import { ref } from 'vue';

export function useImageModal() {
  const isModaleOpen = ref(false);
  const currentImage = ref({ src: '', alt: '' });
  const swiperPopupContent = ref([]);
  
  const body = document.querySelector('body');
  const hamburger = document.querySelector('#hamburger');
  const menu = document.querySelector('#menu');

  const openImageModale = (src, alt, swiperMedia) => {
    currentImage.value = { src, alt };
    swiperPopupContent.value = swiperMedia || [];
    isModaleOpen.value = true;
    toggleBodyScroll(true);
  };

  const closeImageModale = () => {
    isModaleOpen.value = false;
    swiperPopupContent.value = [];
    toggleBodyScroll(false);
  };

  const toggleBodyScroll = (disableScroll) => {
    if (disableScroll) {
      body.classList.add('no-scroll');
      hamburger.style.opacity = 0;
      menu.style.display = 'none';
    } else {
      body.classList.remove('no-scroll');
      menu.style.display = 'flex';
      setTimeout(() => {
        hamburger.style.opacity = 1;
      }, 300);
    }
  };

  return {
    isModaleOpen,
    currentImage,
    swiperPopupContent,
    openImageModale,
    closeImageModale,
  };
}